# mirage
🏖 mirage is a static site generator in Python

## Installation
```
pip install miragepy
```

## Usage
```
mirage <command>

Commands:
  init      Initialize a new site
  build     Build the site
  serve     Serve the site
  deploy    Deploy the site to GitHub Pages
```